"""
AIPTX Beast Mode - Payload Mutations
====================================

Specialized mutation techniques for different vulnerability types.

Includes mutators for:
- Core injection types (SQLi, XSS, CMD)
- Protocol attacks (HTTP Smuggling, HPP, Cache Poisoning)
- Client-side attacks (Prototype Pollution, CORS)
- Server-side attacks (SSRF, SSTI, NoSQL)
- Race conditions
"""

from __future__ import annotations

from aipt_v2.exploitation.mutations.sqli_mutations import (
    SQLiMutator,
    mutate_sqli_payload,
    get_sqli_variants,
)
from aipt_v2.exploitation.mutations.xss_mutations import (
    XSSMutator,
    mutate_xss_payload,
    get_xss_variants,
)
from aipt_v2.exploitation.mutations.cmd_mutations import (
    CMDMutator,
    mutate_cmd_payload,
    get_cmd_variants,
)
from aipt_v2.exploitation.mutations.specialized_mutations import (
    HTTPSmugglingMutator,
    PrototypePollutionMutator,
    CachePoisonMutator,
    HPPMutator,
    SSRFMutator,
    SSTIMutator,
    NoSQLMutator,
    CORSMutator,
    RaceConditionMutator,
    mutate_http_smuggling,
    mutate_prototype_pollution,
    mutate_ssrf,
    mutate_ssti,
    mutate_nosql,
)

__all__ = [
    # SQLi
    "SQLiMutator",
    "mutate_sqli_payload",
    "get_sqli_variants",
    # XSS
    "XSSMutator",
    "mutate_xss_payload",
    "get_xss_variants",
    # Command Injection
    "CMDMutator",
    "mutate_cmd_payload",
    "get_cmd_variants",
    # HTTP Smuggling
    "HTTPSmugglingMutator",
    "mutate_http_smuggling",
    # Prototype Pollution
    "PrototypePollutionMutator",
    "mutate_prototype_pollution",
    # Cache Poisoning
    "CachePoisonMutator",
    # HTTP Parameter Pollution
    "HPPMutator",
    # SSRF
    "SSRFMutator",
    "mutate_ssrf",
    # SSTI
    "SSTIMutator",
    "mutate_ssti",
    # NoSQL Injection
    "NoSQLMutator",
    "mutate_nosql",
    # CORS
    "CORSMutator",
    # Race Condition
    "RaceConditionMutator",
]
